@@ -211,6 +211,12 @@ class StanfordCoreNLP(object):
 
         self.close()
 
+    def __del__(self):
+        try:
+            self.close()
+        except:
+            pass
+
     def close(self):
         """
         This method kills all the child process that created during the run in order
